<!DOCTYPE TS><TS>
<context>
    <name>ConfigForm</name>
    <message>
        <source>Configuration</source>
        <translation></translation>
    </message>
    <message>
        <source>Error variation tolerance</source>
        <translation>Tolérance sur la variance de l&apos;erreur</translation>
    </message>
    <message>
        <source>Sound Capture</source>
        <translation type="obsolete">Capture du son</translation>
    </message>
    <message>
        <source>Auto detect at startup</source>
        <translation type="obsolete">Détection automatique au démarrage</translation>
    </message>
    <message>
        <source>Auto detect</source>
        <translation type="obsolete">Détection automatique</translation>
    </message>
    <message>
        <source>ALSA</source>
        <translation></translation>
    </message>
    <message>
        <source>hw:0</source>
        <translation></translation>
    </message>
    <message>
        <source>Sampling rate</source>
        <translation>Taux d&apos;échantillonnage</translation>
    </message>
    <message>
        <source>set to max</source>
        <translation>maximiser</translation>
    </message>
    <message>
        <source>JACK</source>
        <translation></translation>
    </message>
    <message>
        <source>automaticaly connect at startup to</source>
        <translation>se connecte automatiquement au démarrage</translation>
    </message>
    <message>
        <source>Real-time parameters</source>
        <translation type="obsolete">Paramètres temps-réel</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation type="obsolete">temps de rafraichissement</translation>
    </message>
    <message>
        <source>increase to get less CPU usage but less time resolution</source>
        <translation type="obsolete">Augmente pour alléger le processeur mais perdre de la résolution en temps</translation>
    </message>
    <message>
        <source> ms</source>
        <translation></translation>
    </message>
    <message>
        <source>Sound Analysis</source>
        <translation>Analyse du son</translation>
    </message>
    <message>
        <source>Note Recognition</source>
        <translation type="obsolete">Reconnaissance de notes</translation>
    </message>
    <message>
        <source>Range</source>
        <translation>Tessiture</translation>
    </message>
    <message>
        <source>from half-tones below A3 and above</source>
        <translation type="obsolete">Du plus bas au plus haut demi-ton</translation>
    </message>
    <message>
        <source>min half-tone from A</source>
        <translation type="obsolete">demi-ton minimum depuis A3</translation>
    </message>
    <message>
        <source>max half-tone form A</source>
        <translation type="obsolete">demi-ton maximum depuis A3</translation>
    </message>
    <message>
        <source>Volume treshold</source>
        <translation type="obsolete">Seuil de volume</translation>
    </message>
    <message>
        <source>volume treshold</source>
        <translation type="obsolete">Seuil de volume</translation>
    </message>
    <message>
        <source>ignore sounds below this treshold</source>
        <translation type="obsolete">Ignore le son en dessous de ce seuil</translation>
    </message>
    <message encoding="UTF-8">
        <source> °/..</source>
        <translation type="obsolete">°/..</translation>
    </message>
    <message>
        <source>volume treshold in per thousands !</source>
        <translation type="obsolete">Seuil du volume en pourmilles !</translation>
    </message>
    <message>
        <source>Length factor</source>
        <translation type="obsolete">Facteur de longueur</translation>
    </message>
    <message>
        <source>so much to say ...</source>
        <translation type="obsolete">tellement à dire ...</translation>
    </message>
    <message>
        <source>increase recognition quality at cost of processor usage</source>
        <translation type="obsolete">améliore la qualité de la reconnaissance au dépend du processeur</translation>
    </message>
    <message>
        <source>Test complexity</source>
        <translation type="obsolete">complexité du test</translation>
    </message>
    <message>
        <source>Components treshold</source>
        <translation type="obsolete">seuil des composantes</translation>
    </message>
    <message>
        <source>in per thousands !</source>
        <translation type="obsolete">en pourmilles !</translation>
    </message>
    <message>
        <source>Frequency Analysis</source>
        <translation type="obsolete">Analyse de la fréquence</translation>
    </message>
    <message>
        <source>Number of wave length computed for each analysis</source>
        <translation type="obsolete">Nombre de longueur d&apos;onde calculées pour chaque analyses</translation>
    </message>
    <message>
        <source>Stability Criteria</source>
        <translation type="obsolete">Critères de stabilité</translation>
    </message>
    <message>
        <source>Tolerance of the error variance</source>
        <translation type="obsolete">Tolérance sur la variance de l&apos;erreur</translation>
    </message>
    <message>
        <source>Views</source>
        <translation type="obsolete">Vues</translation>
    </message>
    <message>
        <source>start in full-screen</source>
        <translation type="obsolete">démarre en plein-écran</translation>
    </message>
    <message>
        <source>raise the window to the whole screen (f)</source>
        <translation type="obsolete">Agrandire la fenêtre pour qu&apos;elle prenne tout l&apos;écran (f)</translation>
    </message>
    <message>
        <source>Tonality</source>
        <translation>Tonalité</translation>
    </message>
    <message>
        <source>C (Do)</source>
        <translation></translation>
    </message>
    <message>
        <source>Bb (Sib)</source>
        <translation></translation>
    </message>
    <message>
        <source>Eb (Mib)</source>
        <translation></translation>
    </message>
    <message>
        <source>the tonality of the showed notes name</source>
        <translation type="obsolete">la tonalité des noms des notes</translation>
    </message>
    <message>
        <source>The tonality of the showed notes name.
Usefull for converting notes name to a corresponding instrument tonality (examples: Eb for saxophone, Bb for trumpet, etc.)</source>
        <translation type="obsolete">La tonalité des noms des notes</translation>
    </message>
    <message>
        <source>Notes name</source>
        <translation>Nom des notes</translation>
    </message>
    <message>
        <source>Latin</source>
        <translation></translation>
    </message>
    <message>
        <source>use englo-saxon or latin notes name</source>
        <translation type="obsolete">Utiliser la notation englo-saxonne au latine</translation>
    </message>
    <message>
        <source>Use englo-saxon or latin notes name.
englo-saxon: C D E F G A B
latin: Do Re Mi Fa Sol La Si</source>
        <translation type="obsolete">Utiliser la notation englo-saxonne au latine
englo-saxonne: C D E F G A B
latine: Do Re Mi Fa Sol La Si</translation>
    </message>
    <message>
        <source>Sound History</source>
        <translation type="obsolete">Son</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation type="obsolete">Durée</translation>
    </message>
    <message>
        <source>View max height</source>
        <translation type="obsolete">Hauteur maximum (en pixel)</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="obsolete">Erreur</translation>
    </message>
    <message>
        <source>the length of the average to compute the instrument frequency</source>
        <translation type="obsolete">La longueur de la moyenne pour calculer la férquence</translation>
    </message>
    <message>
        <source>smaller is the value faster the tuner respond, but more unprecise the computed frequency is</source>
        <translation type="obsolete">Plus petite est la valeur, plus vite l&apos;accordeur répond, mais l&apos;accordeur perd en précision</translation>
    </message>
    <message>
        <source>Latency</source>
        <translation>Latence</translation>
    </message>
    <message>
        <source>Wave Sample</source>
        <translation type="obsolete">Échantillon</translation>
    </message>
    <message>
        <source>Show fading away</source>
        <translation type="obsolete">Montrer un estompage</translation>
    </message>
    <message>
        <source>Number of sample keept</source>
        <translation type="obsolete">Nombre d&apos;estompage</translation>
    </message>
    <message>
        <source>Formants</source>
        <translation type="obsolete">Composantes</translation>
    </message>
    <message>
        <source>Number of formants shown</source>
        <translation type="obsolete">Nombre d&apos;harmoniques affichées</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="obsolete">&amp;Aide</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation type="obsolete">&amp;Sauvegarder</translation>
    </message>
    <message>
        <source>Save settings</source>
        <translation type="obsolete">Sauvegarder la configuration</translation>
    </message>
    <message>
        <source>Restore factory settings</source>
        <translation>Restaurer la configuration de départ</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Accepter</translation>
    </message>
    <message>
        <source>Use theses settings and exist configure panel (but don&apos;t save them !)</source>
        <translation type="obsolete">Utiliser cette configuration (mais ne la sauvegarde pas !)</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>A&amp;nnuller</translation>
    </message>
    <message>
        <source>Show volume history</source>
        <translation type="obsolete">Afficher l&apos;historique du volume</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <source>Start in full-screen</source>
        <translation>Démarre en plein-écran</translation>
    </message>
    <message>
        <source>Auto-save configuration and views layout on exit</source>
        <translation>Sauvegarder automatiquement la configuration et la disposition des vues en quittant</translation>
    </message>
    <message>
        <source>Anglo-Saxon</source>
        <translation></translation>
    </message>
    <message>
        <source>use anglo-saxon or latin notes name</source>
        <translation type="obsolete">Utiliser la notation anglo-saxone ou latine</translation>
    </message>
    <message>
        <source>Use anglo-saxon or latin notes name.
englo-saxon: C D E F G A B
latin: Do Re Mi Fa Sol La Si</source>
        <translation type="obsolete">Utiliser la notation anglo-saxone ou latine.
Anglo-saxon: C D E F G A B
Latine: Do Re Mi Fa Sol La Si</translation>
    </message>
    <message>
        <source>&lt;b&gt;To get more options:&lt;/b&gt; right-click every view to show up their properties !</source>
        <translation type="obsolete">&lt;b&gt;Pour obtenir plus d&apos;options:&lt;/b&gt; cliquez les vues avec le boutton droit de la souris pour faire apparaître leurs propriétés !</translation>
    </message>
    <message>
        <source>Volume threshold</source>
        <translation>Seuil de volume</translation>
    </message>
    <message>
        <source>Components threshold</source>
        <translation type="obsolete">Seuil de composantes</translation>
    </message>
    <message>
        <source>Refresh time</source>
        <translation>Temps de rafraîchissement</translation>
    </message>
    <message>
        <source>Time between each sound analysis. Increase to get less CPU usage but less time resolution.</source>
        <translation type="obsolete">Temps entre chaque analyse du son. Augmenter pour réduire l&apos;utilisation du processeur mais baisser la résolution temporelle.</translation>
    </message>
    <message>
        <source>Frequency analysis range.</source>
        <translation type="obsolete">Portée de l&apos;analyse des fréquences.</translation>
    </message>
    <message>
        <source>Minimal half-tone from A3</source>
        <translation type="obsolete">Demi-ton minimum depuis La3</translation>
    </message>
    <message>
        <source>Maximal half-tone form A3</source>
        <translation type="obsolete">Demi-ton maximum depuis La3</translation>
    </message>
    <message>
        <source>Ignore all sounds with volume below this threshold (in perthousands !)(shown has a red line in the graph view).</source>
        <translation type="obsolete">Ignore tout les sons dont le volume est inférieur à ce seuil (en pour-milles !)
(visible sous la forme d&apos;une ligne rouge dans la vue du graphe).</translation>
    </message>
    <message>
        <source>Wave-length average size</source>
        <translation type="obsolete">Taille de la moyenne de la longueur d&apos;onde</translation>
    </message>
    <message>
        <source>Size of the average to compute the frequency in one analysis.</source>
        <translation type="obsolete">Taille de la moyenne utilisée pour calculer la fréquence dans une analyse.</translation>
    </message>
    <message>
        <source>Algorithms</source>
        <translation type="obsolete">Algorithmes</translation>
    </message>
    <message>
        <source>Default algorithm</source>
        <translation type="obsolete">Algorithme par défaut</translation>
    </message>
    <message>
        <source>for microtonal view</source>
        <translation type="obsolete">pour la vue microtonale</translation>
    </message>
    <message>
        <source>Increase recognition quality at cost of processor usage.</source>
        <translation type="obsolete">Améliore la qualité de la reconnaissance au dépend du processeur.</translation>
    </message>
    <message>
        <source>Error noise threshold</source>
        <translation type="obsolete">Seuil du bruit de l&apos;erreur</translation>
    </message>
    <message>
        <source>Consider as valuable all errors below this.</source>
        <translation type="obsolete">Considère comme valable toutes les erreurs en-dessous de ce seuil.</translation>
    </message>
    <message>
        <source>Auto-Correlation (usualy used for Microtonal view)</source>
        <translation type="obsolete">Auto-Correlation (utilisé normalement pour la vue microtonale)</translation>
    </message>
    <message>
        <source>Consider as valuable all errors below this (in per thousands !)</source>
        <translation type="obsolete">Considère comme valable toutes les erreurs en-dessous de ce seuil (en pour-milles !)</translation>
    </message>
    <message>
        <source>Convolution threshold</source>
        <translation type="obsolete">Seuil de convolution</translation>
    </message>
    <message>
        <source>Restore all settings as you just installed the program (need a program restart).</source>
        <translation>Revenir à la configuration comme si le program venait d&apos;être installé (requière un redémarrage du programme).</translation>
    </message>
    <message>
        <source>Raise the window to the whole screen when the program start (f)</source>
        <translation>Agrandit la fenêtre sur tout l&apos;écran lorsque le programme démarre (f)</translation>
    </message>
    <message>
        <source>Use anglo-saxon or latin notes name.
englo-saxon: C D E F G A B
latin: Do Re Mi Fa Sol La </source>
        <translation type="obsolete">Utiliser la notation anglo-saxone ou latine.
Anglo-saxon: C D E F G A B
Latine: Do Re Mi Fa Sol La Si</translation>
    </message>
    <message>
        <source>Consider as unstable all sound with frequency variance above this (in half-tones).</source>
        <translation type="obsolete">Considère comme instable tout les sons dont la variance de l&apos;erreur est au dessus de ce seuil (en demi-ton).</translation>
    </message>
    <message>
        <source>The tonality of the showed notes name.
Usefull for converting notes name to a corresponding instrument tonality.
(examples: Eb for saxophone, Bb for trumpet, etc.)</source>
        <translation type="obsolete">La tonalité des noms des notes.
Utile pour convertir le nom des notes dans la tonalité d&apos;un instrument.
(examples: Mib pour le saxophone, Sib pour la trompette, etc.)</translation>
    </message>
    <message>
        <source>Response of the program and tolerance of holes, scratches, artefacts, etc.
Smaller is the value faster the tuner respond, but more unprecise the computed frequency is.</source>
        <translation type="obsolete">Temps de réponse du program et tolérance des trous, grésillements, etc.
Plus petites est la valeur plus vite le program répond, mais plus la fréquence calculée est instable.</translation>
    </message>
    <message>
        <source>Ignore all sounds with volume below this threshold (in perthousands !)
(shown has a red line in the graph view).</source>
        <translation type="obsolete">Ignore tout les sons dont le volume est inférieur à ce seuil (en pour-milles !)
(visible sous la forme d&apos;une ligne rouge dans la vue du graphe).</translation>
    </message>
    <message>
        <source>Response of the program and tolerance of holes, scratches, artefacts, etc.
Smaller is the value faster the tuner respond, but more unstable the computed frequency is.</source>
        <translation type="obsolete">Temps de réponse du program et tolérance des trous, grésillements, etc.
Plus petites est la valeur plus vite le program répond, mais plus la fréquence calculée est instable.</translation>
    </message>
    <message>
        <source>Client name</source>
        <translation>Nom de client (&quot;client name&quot;)</translation>
    </message>
    <message>
        <source>fmit</source>
        <translation>fmit</translation>
    </message>
    <message>
        <source>Show A3 offset spin box</source>
        <translation type="obsolete">Montrer la boite de décalage du La3</translation>
    </message>
    <message>
        <source>Detect now</source>
        <translation type="obsolete">Détecter maintenant</translation>
    </message>
    <message>
        <source>mix channels if they are multiple (will use the first channel if not checked)</source>
        <translation>mélanger les canaux s&apos;il y en a plusieurs (utilise le premier sinon)</translation>
    </message>
    <message>
        <source>PortAudio</source>
        <translation>PortAudio</translation>
    </message>
    <message>
        <source>Device name</source>
        <translation>Nom du device</translation>
    </message>
    <message>
        <source>default</source>
        <translation>default</translation>
    </message>
    <message>
        <source>OSS</source>
        <translation>OSS</translation>
    </message>
    <message>
        <source>/dev/dsp</source>
        <translation>/dev/dsp</translation>
    </message>
    <message>
        <source>&lt;b&gt;To get more options:&lt;/b&gt;&lt;br&gt;
right-click every view to show up their properties !</source>
        <translation>&lt;b&gt;Pour plus d&apos;options:&lt;/b&gt;&lt;br&gt;
click-droit sur les vues pour afficher leurs propriétés !</translation>
    </message>
    <message>
        <source>Auto detect now</source>
        <translation>Détecter maintenant</translation>
    </message>
    <message>
        <source>Selected capture system</source>
        <translation>Système de capture sélectionné</translation>
    </message>
    <message>
        <source>Auto-detect a working one at startup</source>
        <translation>En détecter un automatiquement au lancement</translation>
    </message>
    <message>
        <source>dB</source>
        <translation>dB</translation>
    </message>
    <message>
        <source>Algorithm</source>
        <translation>Algorithme</translation>
    </message>
    <message>
        <source>Quantizer</source>
        <translation>Quantizer</translation>
    </message>
    <message>
        <source>Frequency refinement</source>
        <translation>Raffinage de la fréquence</translation>
    </message>
    <message>
        <source>Use sub-harmonic audibility treshold</source>
        <translation>Utiliser un seuil d&apos;audibilité de sous-harmonique</translation>
    </message>
    <message>
        <source>Maximum number of harmonics</source>
        <translation>Nombre maximum d&apos;harmoniques</translation>
    </message>
    <message>
        <source>Do not use a too big sampling rate. This is not so much important for pitch recognition, 22050Hz should be largely enough.</source>
        <translation type="obsolete">Ne pas utiliser une fréquence d&apos;échantillonage trop élevée. 22050Hz devrait être largement suffisant dans la pluspart des cas.</translation>
    </message>
    <message>
        <source>Range filtering</source>
        <translation>Filtrage de la portée</translation>
    </message>
    <message>
        <source>Maximum number of periods</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do not use a too big sampling rate. 22050Hz should be largely enough in most cases.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rectangular filter: bad precision, but very fast</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FIR filter: good precision, but more costly in CPU usage</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Window size factor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The tonality of the notes name.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The tonality of the notes name.
Usefull for converting notes name to a corresponding instrument tonality.
(examples: Eb for saxophone, Bb for trumpet, etc.)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use anglo-saxon or latin notes name:
anglo-saxon: C D E F G A B
latin: Do Re Mi Fa Sol La </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use anglo-saxon or latin notes name:
anglo-saxon: C D E F G A B
latin: Do Re Mi Fa Sol La</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show A4 offset spin box</source>
        <translation type="unfinished">Montrer la boite de décalage du La4</translation>
    </message>
    <message>
        <source>right-click every view to show up their properties !</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capture System</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The selected capture system: the sound server, sound library, like:
JACK, ALSA, OSS, PortAudio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto-detect an available capture system at startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto-detect an available capture system at startup.
Even if the capture system is available, it may not works if it&apos;s bad configured.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto-detect an available capture system now.
Even if the capture system is available, it may not works if it&apos;s bad configured.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The name of FMIT under the JACK connection system</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connect automaticaly FMIT to the following source at startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connect automaticaly FMIT to the this source at startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sampling rate of the JACK server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The device name, where the ALSA library have to be connected to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The sampling rate, sampling frequency, number of samples by second ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The sampling rate, sampling frequency, number of samples by second ...
Do not rise it too much. Around 22050Hz should be largely enough in most cases.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Time between each sound analysis.
Increase to get less CPU usage but less time precision.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Frequency analysis range: from the lowest note to the highest from the A4 reference note.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lowest semi-tone from the A4 reference note.
Sometimes, this is usefull to put it higher than -35 to avoid a noise from the sector alimentation.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lowest semi-tone from the A4 reference note in frequency.
Sometimes, this is usefull to put it higher than 50hz to avoid a noise from the sector alimentation.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Highest semi-tone from the A4 reference note.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Highest semi-tone from the A4 reference note in frequency</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filter frequencies belove the lowest semi-tone and above the highest semi-tone to avoid artefacts, noises, in all the following steps of the sound analysis.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filter frequencies belove the lowest semi-tone and above the highest semi-tone
to avoid artefacts, noises, in all the following steps of the sound analysis.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Algorithm settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ignore all sounds with volume below this threshold.
in dB in frequency domain.
(shown has a red line in different views)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ignore weak sub-harmonics.
The treshold is defined between two neighborhood frequency components.
Prevent too-low errors.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Factor defining the window size from the lowest period define by the range.
Bigger is this factor, more stable is the analysis but more CPU the program will need and slower the program will react to sound changes.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Frequency domain fundamental refinement:
Mean of the fundamental relative frequencies of the harmonics.
Choose the number of harmonics to use.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Time domain fundamental refinement:
Mean of period lengths.
Choose the number of period to use.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quantize the analysis results: ignore frequency jumps, fill holes, ignore too short notes.
Smaller is the following value, faster the tuner respond, but more unstable the computed frequency is.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use theses settings and exist configure panel (but don&apos;t save the settings !)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CustomInstrumentTunerForm</name>
    <message>
        <source>Restore Factory Settings</source>
        <translation>Restaurer la configuration de départ</translation>
    </message>
    <message>
        <source>This operation is NOT reversible.
Are you sure you want to lose all your current settings ?</source>
        <translation>Cette opération n&apos;est pas réversible.
Êtes-vous sûr de vouloir perdre votre configuration courrante ?</translation>
    </message>
    <message>
        <source>You can now restart FMIT to get back factory settings</source>
        <translation>Vous pouvez maintenant redémarrer FMIT pour obtenir la configuration de départ</translation>
    </message>
    <message>
        <source>About Free Music Instrument Tuner</source>
        <translation>A propos de Free Music Instrument Tuner</translation>
    </message>
    <message>
        <source>&lt;h3&gt;Version </source>
        <translation></translation>
    </message>
    <message>
        <source>JI value</source>
        <translation type="obsolete">Valeur JI</translation>
    </message>
    <message>
        <source>&lt;/h3&gt;&lt;p&gt;&lt;h3&gt;Website:&lt;/h3&gt;&lt;p&gt;homepage: &lt;a href=&quot;http://home.gna.org/fmit&quot;&gt;http://home.gna.org/fmit&lt;/a&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;p&gt;development site: &lt;a href=&quot;http://gna.org/projects/fmit&quot;&gt;http://gna.org/projects/fmit&lt;/a&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;p&gt;donation link: &lt;a href=&quot;http://home.gna.org/fmit/donation.html&quot;&gt;http://home.gna.org/fmit/donation.html&lt;/a&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;h3&gt;Author:&lt;/h3&gt;&lt;p&gt;Gilles Degottex [gilles.degottex@net2000.ch]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;h3&gt;Packager:&lt;/h3&gt;&lt;p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>about_box</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DialView</name>
    <message>
        <source>Show trace</source>
        <translation type="obsolete">Afficher une trace</translation>
    </message>
    <message>
        <source>Use percentages</source>
        <translation type="obsolete">Utiliser des pourcents</translation>
    </message>
    <message>
        <source>Show tolerance</source>
        <translation type="obsolete">Montrer la tolérance</translation>
    </message>
    <message>
        <source>Use cents</source>
        <translation type="obsolete">Utilise la mesure en cents</translation>
    </message>
    <message>
        <source>Scale range</source>
        <translation type="obsolete">Échelle d&apos;étirement</translation>
    </message>
    <message>
        <source>Scale range (in cents)</source>
        <translation type="obsolete">Échelle d&apos;étirement (en cents)</translation>
    </message>
</context>
<context>
    <name>GLErrorHistory</name>
    <message>
        <source>Error</source>
        <translation type="obsolete">Erreur</translation>
    </message>
    <message>
        <source>Keep previous notes</source>
        <translation type="obsolete">Conserver les anciennes notes</translation>
    </message>
    <message>
        <source>Use percentages</source>
        <translation type="obsolete">Utiliser des pourcents</translation>
    </message>
    <message>
        <source>Use cents</source>
        <translation type="obsolete">Utilise la mesure en cents</translation>
    </message>
    <message>
        <source>Scale range</source>
        <translation type="obsolete">Échelle d&apos;étirement</translation>
    </message>
    <message>
        <source>Scale range (in cents)</source>
        <translation type="obsolete">Échelle d&apos;étirement (en cents)</translation>
    </message>
</context>
<context>
    <name>GLFT</name>
    <message>
        <source>Auto scale</source>
        <translation type="obsolete">Adapte la taille automatiquement</translation>
    </message>
</context>
<context>
    <name>GLFormants</name>
    <message>
        <source>Formants</source>
        <translation type="obsolete">Composantes</translation>
    </message>
    <message>
        <source>Number of formants</source>
        <translation type="obsolete">Nombre de composantes</translation>
    </message>
</context>
<context>
    <name>GLFreqStruct</name>
    <message>
        <source>Number of formants</source>
        <translation type="obsolete">Nombre de composantes</translation>
    </message>
    <message>
        <source>Formants</source>
        <translation type="obsolete">Composantes</translation>
    </message>
    <message>
        <source>Number of harmonics</source>
        <translation type="obsolete">Nombre d&apos;harmoniques</translation>
    </message>
    <message>
        <source>Harmonics</source>
        <translation type="obsolete">Harmoniques</translation>
    </message>
</context>
<context>
    <name>GLGraph</name>
    <message>
        <source>Captured Sound</source>
        <translation type="obsolete">Son</translation>
    </message>
    <message>
        <source>Auto scale</source>
        <translation type="obsolete">Adapte la taille automatiquement</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation type="obsolete">Durée</translation>
    </message>
    <message>
        <source>Max height</source>
        <translation type="obsolete">Hauteur maximale</translation>
    </message>
    <message>
        <source>Show Wave Form</source>
        <translation type="obsolete">Montrer la forme d&apos;onde</translation>
    </message>
    <message>
        <source>Scale factor</source>
        <translation type="obsolete">Facteur d&apos;étirement</translation>
    </message>
</context>
<context>
    <name>GLSample</name>
    <message>
        <source>Wave form sample</source>
        <translation type="obsolete">Echantillon</translation>
    </message>
    <message>
        <source>Show fading</source>
        <translation type="obsolete">Afficher un estompage</translation>
    </message>
    <message>
        <source>Number of fading</source>
        <translation type="obsolete">Nombre d&apos;estompages</translation>
    </message>
</context>
<context>
    <name>GLVolumeHistory</name>
    <message>
        <source>Keep previous notes</source>
        <translation type="obsolete">Conserver les anciennes notes</translation>
    </message>
</context>
<context>
    <name>InstrumentTunerForm</name>
    <message>
        <source>Music Instrument Tuner</source>
        <translation type="obsolete">Accordeur d&apos;instruments de musique</translation>
    </message>
    <message>
        <source>K
e
e
p</source>
        <translation>G
a
r
d
e
r</translation>
    </message>
    <message>
        <source>K</source>
        <translation>G</translation>
    </message>
    <message>
        <source>Keep errors (k)</source>
        <translation>Garder les erreurs (g)</translation>
    </message>
    <message>
        <source>Keep errors</source>
        <translation type="obsolete">Garder les erreurs (g)</translation>
    </message>
    <message>
        <source>Note Stability</source>
        <translation>Stabilité de la note</translation>
    </message>
    <message>
        <source>Stability of the playing note</source>
        <translation type="obsolete">Stabilité de la note jouée</translation>
    </message>
    <message>
        <source>Tuning Frequency</source>
        <translation>Fréquence d&apos;accordage</translation>
    </message>
    <message>
        <source> Hz</source>
        <translation></translation>
    </message>
    <message>
        <source>A3 frequency</source>
        <translation type="obsolete">Fréquence du La3</translation>
    </message>
    <message>
        <source>the frequency error</source>
        <translation type="obsolete">L&apos;erreur</translation>
    </message>
    <message>
        <source>the arrow should be at 12 o&apos;clock for a perfect tuned instrument.
At 9, the instrument is a quarter tone lower.</source>
        <translation type="obsolete">La flèche devrait être à midi pour un instrument parfaitement accordé.
à 9 heure, l&apos;instruement est un quart de ton trop bas.</translation>
    </message>
    <message>
        <source>the dominant note</source>
        <translation type="obsolete">La note dominante</translation>
    </message>
    <message>
        <source>the frequency of the note as it should be</source>
        <translation type="obsolete">La fréquence de la note comme elle devrait être</translation>
    </message>
    <message>
        <source>the instrument frequency</source>
        <translation type="obsolete">La fréquence de la note jouée</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation type="obsolete">Outils</translation>
    </message>
    <message>
        <source>About</source>
        <translation>A propos de</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;A propos de </translation>
    </message>
    <message>
        <source>Show sample</source>
        <translation type="obsolete">Montrer l&apos;échantillon</translation>
    </message>
    <message>
        <source>Show formants</source>
        <translation type="obsolete">Montrer les composantes</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation></translation>
    </message>
    <message>
        <source>Space</source>
        <translation>Espace</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation>Configurer</translation>
    </message>
    <message>
        <source>Show captured sound</source>
        <translation type="obsolete">Montrer le son capturé</translation>
    </message>
    <message>
        <source>Show error History</source>
        <translation type="obsolete">Montrer l&apos;historique de l&apos;erreur</translation>
    </message>
    <message>
        <source>Save settings</source>
        <translation>Sauvegarder la configuration</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation></translation>
    </message>
    <message>
        <source>Reset</source>
        <translation type="obsolete">Redémarre</translation>
    </message>
    <message>
        <source>Reset capture system</source>
        <translation type="obsolete">Redémarrer la capture du son</translation>
    </message>
    <message>
        <source>capture stability</source>
        <translation type="obsolete">Stabilité de la capture</translation>
    </message>
    <message>
        <source>Views</source>
        <translation>Vues</translation>
    </message>
    <message>
        <source>Restore Factory Settings</source>
        <translation type="obsolete">Restaurer la configuration de départ</translation>
    </message>
    <message>
        <source>This operation is NOT reversible.
Are you sure you want to lose all your current settings ?</source>
        <translation type="obsolete">Cette opération n&apos;est pas réversible. Êtes-vous sûr de vouloir perdre votre configuration courrante ?</translation>
    </message>
    <message>
        <source>You can now restart FMIT to get back factory settings</source>
        <translation type="obsolete">Vous pouvez maintenant redémarrer FMIT pour obtenir la configuration de départ</translation>
    </message>
    <message>
        <source>Do not clear histories between notes.</source>
        <translation type="obsolete">N&apos;efface pas les historiques entre les notes.</translation>
    </message>
    <message>
        <source>Green if the note is stable enough, red if not and grey if there is no sound.</source>
        <translation type="obsolete">Vert si la note est assez stable, rouge sinon et gris s&apos;il n&apos;y a pas de son.</translation>
    </message>
    <message>
        <source>the A3 frequency</source>
        <translation type="obsolete">la fréquence du La3</translation>
    </message>
    <message>
        <source>The played note frequency</source>
        <translation type="obsolete">La fréquence de la note jouée</translation>
    </message>
    <message>
        <source>The frequency of the current played note.</source>
        <translation type="obsolete">La fréquence de la note jouée.</translation>
    </message>
    <message>
        <source>The recognized note</source>
        <translation>La note reconnue</translation>
    </message>
    <message>
        <source>The frequency of the note as it should be.</source>
        <translation type="obsolete">La fréquence de la note comme elle devrait être.</translation>
    </message>
    <message>
        <source>Capture stability</source>
        <translation type="obsolete">La stabilité de la capture du son</translation>
    </message>
    <message>
        <source>Green if FMIT is capturing sound, red if something goes wrong (sound server unavailable, drivers not loaded, etc.)</source>
        <translation type="obsolete">Vert si le program est en train de capturer du son, rouge si quelque chose ne va pas (serveur son indisponible, drivers pas chargés, etc.)</translation>
    </message>
    <message>
        <source>Put in pause state to use less processor has possible.</source>
        <translation>Met le program en état de pause pour utiliser un minimum de processeur.</translation>
    </message>
    <message>
        <source>Save configure panel settings, views settings and window size.</source>
        <translation>Sauvegarde les réglages du panneau de configuration, les réglages des vues et la taille de la fenêtre.</translation>
    </message>
    <message>
        <source>Stop, reload settings and restart the capture sound system.</source>
        <translation type="obsolete">Arrête, recharger les réglages et redémarre la capture du son.</translation>
    </message>
    <message>
        <source>Green if the program is capturing sound, red if something goes wrong (sound server unavailable, drivers not loaded, etc.)</source>
        <translation type="obsolete">Vert si le program est en train de capturer du son, rouge si quelque chose ne va pas (serveur son indisponible, drivers pas chargés, etc.)</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configurations</translation>
    </message>
    <message>
        <source>Offset</source>
        <translation>Décalage</translation>
    </message>
    <message>
        <source>Offset in cents on the tuning frequency</source>
        <translation>Décalage en cents depuis la fréquence d&apos;accordage</translation>
    </message>
    <message>
        <source> cents</source>
        <translation>cents</translation>
    </message>
    <message>
        <source>Red if capture system is not working&lt;br/&gt;
Grey if capture system is ok, but there is no sound enough&lt;br/&gt;
Orange if analysis conditions are bad (like saturation)&lt;br/&gt;
Green if a note is beeing catured and conditions are ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Free Music Instrument Tuner</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do not clear graphs between notes (for error and volume graphs only)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Volume with dB scale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Volume with dB scale.
Computed from in the frequency domaine, from the max bin.
The maximum is reached when the signal energy is maximal NOT when the sound saturate in time domaine.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>the tuning frequency: A4 frequency</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Offset in cents from the tuning frequency</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The frequency of the current played note</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The frequency of the note as it should be</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About FMIT</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invoke the about box</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Put in pause state, stop the capture, the sound analysis and all views</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>JustIntonationView</name>
    <message>
        <source>Unkown filename: &apos;</source>
        <translation type="obsolete">Nom de fichier inconnu: &apos;</translation>
    </message>
    <message>
        <source>Keep root to left side</source>
        <translation type="obsolete">Conserver la tonique à l&apos;extrémité gauche</translation>
    </message>
    <message>
        <source>Load Scala file ...</source>
        <translation type="obsolete">Charger un fichier Scala ...</translation>
    </message>
    <message>
        <source>used scale</source>
        <translation type="obsolete">Échelle utilisée</translation>
    </message>
    <message>
        <source>Open scale file</source>
        <translation type="obsolete">Ouvrir un fichier d&apos;échelle</translation>
    </message>
    <message>
        <source>Scale name already exist</source>
        <translation type="obsolete">Nom d&apos;échelle déjà existant</translation>
    </message>
    <message>
        <source>Invalid file content !</source>
        <translation type="obsolete">Contenu de fichier invalid !</translation>
    </message>
</context>
<context>
    <name>JustIntonationView::ScalePreview</name>
    <message>
        <source>&lt;b&gt;name:&lt;/b&gt; </source>
        <translation type="obsolete">&lt;b&gt;nom:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;number of ratio:&lt;/b&gt; </source>
        <translation type="obsolete">&lt;b&gt;nombre de valeurs:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Invalid Scala file: </source>
        <translation type="obsolete">Fichier Scala invalid:</translation>
    </message>
</context>
<context>
    <name>MicrotonalView</name>
    <message>
        <source>Unkown filename: &apos;</source>
        <translation type="obsolete">Nom de fichier inconnu: &apos;</translation>
    </message>
    <message>
        <source>Keep root to left side</source>
        <translation type="obsolete">Conserver la tonique à l&apos;extrémité gauche</translation>
    </message>
    <message>
        <source>Load Scala file ...</source>
        <translation type="obsolete">Charger un fichier Scala ...</translation>
    </message>
    <message>
        <source>used scale</source>
        <translation type="obsolete">Échelle utilisée</translation>
    </message>
    <message>
        <source>Open scale file</source>
        <translation type="obsolete">Ouvrir un fichier d&apos;échelle</translation>
    </message>
    <message>
        <source>Scale name already exist</source>
        <translation type="obsolete">Nom d&apos;échelle déjà existant</translation>
    </message>
    <message>
        <source>Invalid file content !</source>
        <translation type="obsolete">Contenu de fichier invalid !</translation>
    </message>
    <message>
        <source>Root&apos;s octave</source>
        <translation type="obsolete">Octave de base</translation>
    </message>
</context>
<context>
    <name>MicrotonalView::ScalePreview</name>
    <message>
        <source>&lt;b&gt;name:&lt;/b&gt; </source>
        <translation type="obsolete">&lt;b&gt;nom:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;number of ratio:&lt;/b&gt; </source>
        <translation type="obsolete">&lt;b&gt;nombre de valeures:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Invalid Scala file: </source>
        <translation type="obsolete">Fichier Scala invalid:</translation>
    </message>
</context>
<context>
    <name>QWidget</name>
    <message>
        <source>Show </source>
        <translation type="obsolete">Afficher</translation>
    </message>
    <message>
        <source> view</source>
        <translation type="obsolete">vue</translation>
    </message>
</context>
</TS>
